Class: Aws::IoTJobsDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTJobsDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotjobsdataplane/client.rb,
sig/client.rbs
Overview
An API client for IoTJobsDataPlane. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTJobsDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DescribeJobExecutionResponseSuccess, _GetPendingJobExecutionsResponseSuccess, _StartCommandExecutionResponseSuccess, _StartNextPendingJobExecutionResponseSuccess, _UpdateJobExecutionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
-
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
-
#start_command_execution(params = {}) ⇒ Types::StartCommandExecutionResponse
Using the command created with the
CreateCommandAPI, start a command execution on a specific device. -
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
-
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
850 851 852 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 850 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
853 854 855 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 853 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 823 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTJobsDataPlane') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotjobsdataplane' context[:gem_version] = '1.83.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
Requires permission to access the DescribeJobExecution action.
86 |
# File 'sig/client.rbs', line 86
def describe_job_execution: (
|
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
Requires permission to access the GetPendingJobExecutions action.
100 |
# File 'sig/client.rbs', line 100
def get_pending_job_executions: (
|
#start_command_execution(params = {}) ⇒ Types::StartCommandExecutionResponse
Using the command created with the CreateCommand API, start a
command execution on a specific device.
110 |
# File 'sig/client.rbs', line 110
def start_command_execution: (
|
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
Requires permission to access the StartNextPendingJobExecution action.
132 |
# File 'sig/client.rbs', line 132
def start_next_pending_job_execution: (
|
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Requires permission to access the UpdateJobExecution action.
145 |
# File 'sig/client.rbs', line 145
def update_job_execution: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
843 844 845 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 843 def waiter_names [] end |