Class: Aws::IoTJobsDataPlane::Types::DescribeJobExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotjobsdataplane/types.rb

Overview

Note:

When making an API call, you may pass DescribeJobExecutionRequest data as a hash:

{
  job_id: "DescribeJobExecutionJobId", # required
  thing_name: "ThingName", # required
  include_job_document: false,
  execution_number: 1,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_numberInteger

Optional. A number that identifies a particular job execution on a particular device. If not specified, the latest job execution is returned.

Returns:

  • (Integer)


55
56
57
58
59
60
61
62
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 55

class DescribeJobExecutionRequest < Struct.new(
  :job_id,
  :thing_name,
  :include_job_document,
  :execution_number)
  SENSITIVE = []
  include Aws::Structure
end

#include_job_documentBoolean

Optional. When set to true, the response contains the job document. The default is false.

Returns:

  • (Boolean)


55
56
57
58
59
60
61
62
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 55

class DescribeJobExecutionRequest < Struct.new(
  :job_id,
  :thing_name,
  :include_job_document,
  :execution_number)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier assigned to this job when it was created.

Returns:

  • (String)


55
56
57
58
59
60
61
62
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 55

class DescribeJobExecutionRequest < Struct.new(
  :job_id,
  :thing_name,
  :include_job_document,
  :execution_number)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The thing name associated with the device the job execution is running on.

Returns:

  • (String)


55
56
57
58
59
60
61
62
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 55

class DescribeJobExecutionRequest < Struct.new(
  :job_id,
  :thing_name,
  :include_job_document,
  :execution_number)
  SENSITIVE = []
  include Aws::Structure
end