Class: Aws::IoTJobsDataPlane::Types::GetPendingJobExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTJobsDataPlane::Types::GetPendingJobExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotjobsdataplane/types.rb
Overview
Note:
When making an API call, you may pass GetPendingJobExecutionsRequest data as a hash:
{
thing_name: "ThingName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#thing_name ⇒ String
The name of the thing that is executing the job.
Instance Attribute Details
#thing_name ⇒ String
The name of the thing that is executing the job.
85 86 87 88 89 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 85 class GetPendingJobExecutionsRequest < Struct.new( :thing_name) SENSITIVE = [] include Aws::Structure end |