Class: Aws::IoTJobsDataPlane::Types::JobExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTJobsDataPlane::Types::JobExecution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotjobsdataplane/types.rb
Overview
Contains data about a job execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_seconds_before_timed_out ⇒ Integer
The estimated number of seconds that remain before the job execution status will be changed to `TIMED_OUT`.
-
#execution_number ⇒ Integer
A number that identifies a particular job execution on a particular device.
-
#job_document ⇒ String
The content of the job document.
-
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
-
#last_updated_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was last updated.
-
#queued_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was enqueued.
-
#started_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was started.
-
#status ⇒ String
The status of the job execution.
-
#status_details ⇒ Hash<String,String>
A collection of name/value pairs that describe the status of the job execution.
-
#thing_name ⇒ String
The name of the thing that is executing the job.
-
#version_number ⇒ Integer
The version of the job execution.
Instance Attribute Details
#approximate_seconds_before_timed_out ⇒ Integer
The estimated number of seconds that remain before the job execution status will be changed to `TIMED_OUT`.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#execution_number ⇒ Integer
A number that identifies a particular job execution on a particular device. It can be used later in commands that return or update job execution information.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#job_document ⇒ String
The content of the job document.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was last updated.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#queued_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was enqueued.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The time, in milliseconds since the epoch, when the job execution was started.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job execution. Can be one of: “QUEUED”, “IN_PROGRESS”, “FAILED”, “SUCCESS”, “CANCELED”, “REJECTED”, or “REMOVED”.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Hash<String,String>
A collection of name/value pairs that describe the status of the job execution.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing that is executing the job.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version of the job execution. Job execution versions are incremented each time they are updated by a device.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 191 class JobExecution < Struct.new( :job_id, :thing_name, :status, :status_details, :queued_at, :started_at, :last_updated_at, :approximate_seconds_before_timed_out, :version_number, :execution_number, :job_document) SENSITIVE = [] include Aws::Structure end |