Class: Aws::IoTJobsDataPlane::Types::UpdateJobExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTJobsDataPlane::Types::UpdateJobExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotjobsdataplane/types.rb
Overview
When making an API call, you may pass UpdateJobExecutionRequest data as a hash:
{
job_id: "JobId", # required
thing_name: "ThingName", # required
status: "QUEUED", # required, accepts QUEUED, IN_PROGRESS, SUCCEEDED, FAILED, TIMED_OUT, REJECTED, REMOVED, CANCELED
status_details: {
"DetailsKey" => "DetailsValue",
},
step_timeout_in_minutes: 1,
expected_version: 1,
include_job_execution_state: false,
include_job_document: false,
execution_number: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_number ⇒ Integer
Optional.
-
#expected_version ⇒ Integer
Optional.
-
#include_job_document ⇒ Boolean
Optional.
-
#include_job_execution_state ⇒ Boolean
Optional.
-
#job_id ⇒ String
The unique identifier assigned to this job when it was created.
-
#status ⇒ String
The new status for the job execution (IN_PROGRESS, FAILED, SUCCESS, or REJECTED).
-
#status_details ⇒ Hash<String,String>
Optional.
-
#step_timeout_in_minutes ⇒ Integer
Specifies the amount of time this device has to finish execution of this job.
-
#thing_name ⇒ String
The name of the thing associated with the device.
Instance Attribute Details
#execution_number ⇒ Integer
Optional. A number that identifies a particular job execution on a particular device.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
Optional. The expected current version of the job execution. Each time you update the job execution, its version is incremented. If the version of the job execution stored in Jobs does not match, the update is rejected with a VersionMismatch error, and an ErrorResponse that contains the current job execution status data is returned. (This makes it unnecessary to perform a separate DescribeJobExecution request in order to obtain the job execution status data.)
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#include_job_document ⇒ Boolean
Optional. When set to true, the response contains the job document. The default is false.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#include_job_execution_state ⇒ Boolean
Optional. When included and set to true, the response contains the JobExecutionState data. The default is false.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier assigned to this job when it was created.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The new status for the job execution (IN_PROGRESS, FAILED, SUCCESS, or REJECTED). This must be specified on every update.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Hash<String,String>
Optional. A collection of name/value pairs that describe the status of the job execution. If not specified, the statusDetails are unchanged.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#step_timeout_in_minutes ⇒ Integer
Specifies the amount of time this device has to finish execution of this job. If the job execution status is not set to a terminal state before this timer expires, or before the timer is reset (by again calling `UpdateJobExecution`, setting the status to `IN_PROGRESS` and specifying a new timeout value in this field) the job execution status will be automatically set to `TIMED_OUT`. Note that setting or resetting this timeout has no effect on that job execution timeout which may have been specified when the job was created (`CreateJob` using field `timeoutConfig`).
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing associated with the device.
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/types.rb', line 451 class UpdateJobExecutionRequest < Struct.new( :job_id, :thing_name, :status, :status_details, :step_timeout_in_minutes, :expected_version, :include_job_execution_state, :include_job_document, :execution_number) SENSITIVE = [] include Aws::Structure end |