Class: Aws::IoTJobsDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTJobsDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotjobsdataplane/client.rb
Overview
An API client for IoTJobsDataPlane. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTJobsDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
-
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
-
#start_command_execution(params = {}) ⇒ Types::StartCommandExecutionResponse
Using the command created with the ‘CreateCommand` API, start a command execution on a specific device.
-
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
-
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
855 856 857 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 855 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
858 859 860 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 858 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 828 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTJobsDataPlane') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotjobsdataplane' context[:gem_version] = '1.70.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
Requires permission to access the [DescribeJobExecution] action.
536 537 538 539 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 536 def describe_job_execution(params = {}, = {}) req = build_request(:describe_job_execution, params) req.send_request() end |
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
Requires permission to access the [GetPendingJobExecutions] action.
583 584 585 586 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 583 def get_pending_job_executions(params = {}, = {}) req = build_request(:get_pending_job_executions, params) req.send_request() end |
#start_command_execution(params = {}) ⇒ Types::StartCommandExecutionResponse
Using the command created with the ‘CreateCommand` API, start a command execution on a specific device.
652 653 654 655 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 652 def start_command_execution(params = {}, = {}) req = build_request(:start_command_execution, params) req.send_request() end |
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
Requires permission to access the [StartNextPendingJobExecution] action.
722 723 724 725 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 722 def start_next_pending_job_execution(params = {}, = {}) req = build_request(:start_next_pending_job_execution, params) req.send_request() end |
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Requires permission to access the [UpdateJobExecution] action.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotjobsdataplane.html
819 820 821 822 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 819 def update_job_execution(params = {}, = {}) req = build_request(:update_job_execution, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
848 849 850 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 848 def waiter_names [] end |