Class: Aws::IoTJobsDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTJobsDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotjobsdataplane/client.rb
Overview
An API client for IoTJobsDataPlane. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTJobsDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
-
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
-
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
-
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
446 447 448 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 446 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
718 719 720 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 718 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
721 722 723 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 721 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 691 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTJobsDataPlane') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotjobsdataplane' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
500 501 502 503 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 500 def describe_job_execution(params = {}, = {}) req = build_request(:describe_job_execution, params) req.send_request() end |
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
541 542 543 544 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 541 def get_pending_job_executions(params = {}, = {}) req = build_request(:get_pending_job_executions, params) req.send_request() end |
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
598 599 600 601 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 598 def start_next_pending_job_execution(params = {}, = {}) req = build_request(:start_next_pending_job_execution, params) req.send_request() end |
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
682 683 684 685 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 682 def update_job_execution(params = {}, = {}) req = build_request(:update_job_execution, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
711 712 713 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 711 def waiter_names [] end |