Class: Aws::IoTJobsDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTJobsDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotjobsdataplane/client.rb
Overview
An API client for IoTJobsDataPlane. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTJobsDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
-
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
-
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
-
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
381 382 383 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 381 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
648 649 650 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 648 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
651 652 653 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 651 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 626 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iotjobsdataplane' context[:gem_version] = '1.42.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
435 436 437 438 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 435 def describe_job_execution(params = {}, = {}) req = build_request(:describe_job_execution, params) req.send_request() end |
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
476 477 478 479 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 476 def get_pending_job_executions(params = {}, = {}) req = build_request(:get_pending_job_executions, params) req.send_request() end |
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
533 534 535 536 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 533 def start_next_pending_job_execution(params = {}, = {}) req = build_request(:start_next_pending_job_execution, params) req.send_request() end |
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
617 618 619 620 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 617 def update_job_execution(params = {}, = {}) req = build_request(:update_job_execution, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
641 642 643 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 641 def waiter_names [] end |