Class: Aws::IoTJobsDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTJobsDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotjobsdataplane/client.rb
Overview
An API client for IoTJobsDataPlane. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::IoTJobsDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
-
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
-
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
-
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
632 633 634 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 632 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
635 636 637 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 635 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 610 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iotjobsdataplane' context[:gem_version] = '1.38.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_job_execution(params = {}) ⇒ Types::DescribeJobExecutionResponse
Gets details of a job execution.
419 420 421 422 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 419 def describe_job_execution(params = {}, = {}) req = build_request(:describe_job_execution, params) req.send_request() end |
#get_pending_job_executions(params = {}) ⇒ Types::GetPendingJobExecutionsResponse
Gets the list of all jobs for a thing that are not in a terminal status.
460 461 462 463 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 460 def get_pending_job_executions(params = {}, = {}) req = build_request(:get_pending_job_executions, params) req.send_request() end |
#start_next_pending_job_execution(params = {}) ⇒ Types::StartNextPendingJobExecutionResponse
Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.
517 518 519 520 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 517 def start_next_pending_job_execution(params = {}, = {}) req = build_request(:start_next_pending_job_execution, params) req.send_request() end |
#update_job_execution(params = {}) ⇒ Types::UpdateJobExecutionResponse
Updates the status of a job execution.
601 602 603 604 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 601 def update_job_execution(params = {}, = {}) req = build_request(:update_job_execution, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
625 626 627 |
# File 'lib/aws-sdk-iotjobsdataplane/client.rb', line 625 def waiter_names [] end |